@@ -1,11 +1,9 @@
 #' @keywords internal
-"_PACKAGE"
-
-## usethis namespace: start
 #' @importFrom httr2 iterate_with_offset
 #' @importFrom httr2 req_error
 #' @importFrom httr2 req_perform
 #' @importFrom httr2 req_perform_iterative
+#' @importFrom httr2 req_perform_sequential
 #' @importFrom httr2 req_url_path_append
 #' @importFrom httr2 req_url_query
 #' @importFrom httr2 req_user_agent
@@ -17,5 +15,4 @@
 #' @importFrom httr2 resp_content_type
 #' @importFrom httr2 resp_status
 #' @importFrom httr2 resps_data
-## usethis namespace: end
-NULL
+"_PACKAGE"
